<?php

namespace InternalApi\Middleware;

use Closure;
use Illuminate\Http\JsonResponse;
use Illuminate\Support\Str;

class InternalApi
{

    public function __construct()
    {
        app()->configure('internal_api');
    }

    /**
     * Handle an incoming request.
     *
     * @param  \Illuminate\Http\Request $request
     * @param  \Closure $next
     * @return mixed
     */
    public function handle($request, Closure $next)
    {
        $ip = $request->getClientIp();

        if (!Str::startsWith($ip, [
            '127.0.0.', '192.168.', '10.0.'
        ])) {
            return new JsonResponse('', 404);
        }

        $params = $request->all();

        if (empty($params['appid'])) {
            $data = ['error' => '参数错误',];
            return new JsonResponse($data, 403);
        }

        if (empty($params['timestamp'])) {
            $data = ['error' => '签名已过有效期',];
            return new JsonResponse($data, 403);
        } elseif (intval($params['timestamp']) + 60 < time()) {
            $data = ['error' => '签名已过有效期',];
            return new JsonResponse($data, 403);
        }

        $sign = $this->sign($params);
        if ($sign != $params['sign']) {
            $data = [
                'error' => '签名错误',
            ];
            return new JsonResponse($data, 403);
        }

        return $next($request);
    }

    protected function sign($params)
    {
        $key = config('internal_api.server.' . $params['appid']);
        unset($params['sign']);
        ksort($params);
        $str = http_build_query($params, null, '&');
        return md5($str . $key);
    }

}
